.. include:: links.inc

Welcome to the documentation!
=============================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   auto_examples/index.rst
   api
   maintaining
   whats_new


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

